pub(crate) enum ChosenLevel {
Unset(Level),
NoOutput,
Level(Level),
}Expand description
Encodes the verbosity level chosen by the user through CLI arguments.
Variants
Unset(Level)
Not set. We still store the default level passed as a type argument in Verbosity
NoOutput
No output at all requested (quiet mode)
Level(Level)
Specific log level selected