pub enum Tracer {
Otlp,
Tracy,
ChromeStyle,
}Available on crate features
otlp or tracy or chrome only.Variants
Otlp
Available on crate feature
otlp only.Tracy
Available on crate feature
tracy only.ChromeStyle
Available on crate feature
chrome only.Trait Implementations
Sourceimpl EnumSetConstHelper for Tracer
impl EnumSetConstHelper for Tracer
Sourceconst CONST_INIT_HELPER: __EnumSetInitHelper = __EnumSetInitHelper
const CONST_INIT_HELPER: __EnumSetInitHelper = __EnumSetInitHelper
The instance of the
ConstInitHelper.Sourceconst CONST_OP_HELPER: __EnumSetOpHelper = __EnumSetOpHelper
const CONST_OP_HELPER: __EnumSetOpHelper = __EnumSetOpHelper
The instance of the
ConstOpHelper.Sourcetype ConstInitHelper = __EnumSetInitHelper
type ConstInitHelper = __EnumSetInitHelper
A helper type used to convert values to EnumSets at compile-time.
Sourcetype ConstOpHelper = __EnumSetOpHelper
type ConstOpHelper = __EnumSetOpHelper
A helper type used to implement compile-time operations on enums.
Sourceimpl EnumSetTypePrivate for Tracer
impl EnumSetTypePrivate for Tracer
Sourceconst ALL_BITS: Self::Repr = {transmute(0x07): <Tracer as enumset::__internal::EnumSetTypePrivate>::Repr}
const ALL_BITS: Self::Repr = {transmute(0x07): <Tracer as enumset::__internal::EnumSetTypePrivate>::Repr}
A mask of bits that are valid in the bitset.
Sourceconst VARIANT_COUNT: u32 = 3u32
const VARIANT_COUNT: u32 = 3u32
The number of variants in the bitset.
Sourcefn enum_into_u32(self) -> u32
fn enum_into_u32(self) -> u32
Converts an enum of this type into its bit position.
Sourceunsafe fn enum_from_u32(val: u32) -> Self
unsafe fn enum_from_u32(val: u32) -> Self
Converts a bit position into an enum value.
Sourceunsafe fn enum_from_u32_checked(val: u32) -> Self
unsafe fn enum_from_u32_checked(val: u32) -> Self
Converts a bit position into an enum value, with an debug_assert.
impl Copy for Tracer
impl EnumSetType for Tracer
impl Eq for Tracer