pub(crate) fn construct_filter<S>(level: ChosenLevel) -> impl Filter<S>Expand description
Helper assembling a filter filtering events for the ChosenLevel.
pub(crate) fn construct_filter<S>(level: ChosenLevel) -> impl Filter<S>Helper assembling a filter filtering events for the ChosenLevel.