send_trace

Function send_trace 

pub fn send_trace<T>(request: Request<T>) -> Result<Request<T>, Box<Status>>
Available on crate feature tonic only.
Trace context propagation: send the trace context by injecting it into the metadata of the given request. This only injects the current span if the otlp feature is also enabled.