pub(crate) struct TracersValueParser(pub(crate) EnumValueParser<Tracer>);Available on crate feature
clap and (crate features otlp or tracy or chrome) only.Expand description
A TypedValueParser for EnumSet<Tracer> that parses either a single tracer or
an empty string.
This will always return either a single element set or an empty set depending on the input string either being the name of a tracer or empty.
Tuple Fields
0: EnumValueParser<Tracer>Trait Implementations
Sourceimpl Clone for TracersValueParser
impl Clone for TracersValueParser
Sourcefn clone(&self) -> TracersValueParser
fn clone(&self) -> TracersValueParser
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TracersValueParser
impl Debug for TracersValueParser
Sourceimpl Default for TracersValueParser
impl Default for TracersValueParser
Sourcefn default() -> TracersValueParser
fn default() -> TracersValueParser
Returns the “default value” for a type. Read more
Sourceimpl TypedValueParser for TracersValueParser
impl TypedValueParser for TracersValueParser
Sourcefn parse_ref(
&self,
cmd: &Command,
arg: Option<&Arg>,
value: &OsStr,
) -> Result<Self::Value, Error>
fn parse_ref( &self, cmd: &Command, arg: Option<&Arg>, value: &OsStr, ) -> Result<Self::Value, Error>
Parse the argument value Read more
Sourcefn possible_values(
&self,
) -> Option<Box<dyn Iterator<Item = PossibleValue> + '_>>
fn possible_values( &self, ) -> Option<Box<dyn Iterator<Item = PossibleValue> + '_>>
Reflect on enumerated value properties Read more
Sourcefn parse_ref_(
&self,
cmd: &Command,
arg: Option<&Arg>,
value: &OsStr,
_source: ValueSource,
) -> Result<Self::Value, Error>
fn parse_ref_( &self, cmd: &Command, arg: Option<&Arg>, value: &OsStr, _source: ValueSource, ) -> Result<Self::Value, Error>
Parse the argument value Read more
Sourcefn parse(
&self,
cmd: &Command,
arg: Option<&Arg>,
value: OsString,
) -> Result<Self::Value, Error>
fn parse( &self, cmd: &Command, arg: Option<&Arg>, value: OsString, ) -> Result<Self::Value, Error>
Parse the argument value Read more
Sourcefn parse_(
&self,
cmd: &Command,
arg: Option<&Arg>,
value: OsString,
_source: ValueSource,
) -> Result<Self::Value, Error>
fn parse_( &self, cmd: &Command, arg: Option<&Arg>, value: OsString, _source: ValueSource, ) -> Result<Self::Value, Error>
Parse the argument value Read more
Sourcefn map<T, F>(self, func: F) -> MapValueParser<Self, F>
fn map<T, F>(self, func: F) -> MapValueParser<Self, F>
Adapt a
TypedValueParser from one value to another Read moreAuto Trait Implementations
impl Freeze for TracersValueParser
impl RefUnwindSafe for TracersValueParser
impl Send for TracersValueParser
impl Sync for TracersValueParser
impl Unpin for TracersValueParser
impl UnsafeUnpin for TracersValueParser
impl UnwindSafe for TracersValueParser