TracingBuilder

Struct TracingBuilder 

pub struct TracingBuilder {
    pub(crate) disable_progress_bars: bool,
    pub(crate) tracers: EnumSet<Tracer>,
    pub(crate) level: ChosenLevel,
}

Fields

disable_progress_bars: booltracers: EnumSet<Tracer>
Available on crate features otlp or tracy or chrome only.
level: ChosenLevel

Implementations

Source

impl TracingBuilder

pub fn enable_tracer(self, tracer: Tracer) -> TracingBuilder

Available on crate features otlp or tracy or chrome only.

Enable the given tracer

pub fn enable_tracers<I>(self, tracers: I) -> TracingBuilder
where I: IntoIterator<Item = Tracer>,

Available on crate features otlp or tracy or chrome only.

Enable the given tracers

pub fn disable_progress_bars(self) -> TracingBuilder

Disable progress bars explicitly, even though they would still match the chosen log level.

pub fn build(self) -> Result<TracingHandle, Error>

This will setup tracing based on the configuration passed in. It will setup a stderr writer output layer and configure EnvFilter to honor RUST_LOG. The EnvFilter will be applied to all configured layers, also otlp.

It will also configure otlp if the feature is enabled and a service_name was provided. It will then correctly setup a channel which is later used for flushing the provider.

pub fn build_with_additional<L>( self, additional_layer: L, ) -> Result<TracingHandle, Error>
where L: Layer<Registry> + Send + Sync + 'static,

Similar to build() but allows passing in an additional tracing Layer.

This method is generic over the Layer to avoid the runtime cost of dynamic dispatch. While it only allows passing a single Layer, it can be composed of multiple ones:

build_with_additional(
  fmt::layer()
    .and_then(some_other_layer)
    .and_then(yet_another_layer)
    .with_filter(my_filter)
)
pub fn handle_verbosity_flags<L: LogLevel>(self, args: &Verbosity<L>) -> Self

Available on crate feature clap only.

Configure with verbosity flags.

pub fn handle_tracing_args<L: LogLevel>(self, args: &TracingArgs<L>) -> Self

Available on crate feature clap only.

Configure with the tracing-related args.